#[non_exhaustive]pub enum AnyGlobalAccountDataEvent {
Show 14 variants
Direct(DirectEvent),
DoNotDisturb(DoNotDisturbEvent),
IdentityServer(IdentityServerEvent),
InvitePermissionConfig(InvitePermissionConfigEvent),
UnstableInvitePermissionConfig(UnstableInvitePermissionConfigEvent),
IgnoredUserList(IgnoredUserListEvent),
PushRules(PushRulesEvent),
SecretStorageDefaultKey(SecretStorageDefaultKeyEvent),
SecretStorageKey(SecretStorageKeyEvent),
MediaPreviewConfig(GlobalMediaPreviewConfigEvent),
UnstableMediaPreviewConfig(GlobalUnstableMediaPreviewConfigEvent),
AccountImagePack(AccountImagePackEvent),
ImagePackRooms(ImagePackRoomsEvent),
RecentEmoji(RecentEmojiEvent),
}Expand description
Any global account data event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Direct(DirectEvent)
m.direct
DoNotDisturb(DoNotDisturbEvent)
m.do_not_disturb
This variant uses the unstable type dm.filament.do_not_disturb.
This variant can also be deserialized from the m.do_not_disturb type.
IdentityServer(IdentityServerEvent)
m.identity_server
InvitePermissionConfig(InvitePermissionConfigEvent)
m.invite_permission_config
UnstableInvitePermissionConfig(UnstableInvitePermissionConfigEvent)
org.matrix.msc4380.invite_permission_config
IgnoredUserList(IgnoredUserListEvent)
m.ignored_user_list
PushRules(PushRulesEvent)
m.push_rules
SecretStorageDefaultKey(SecretStorageDefaultKeyEvent)
m.secret_storage.default_key
SecretStorageKey(SecretStorageKeyEvent)
m.secret_storage.key.*
MediaPreviewConfig(GlobalMediaPreviewConfigEvent)
m.media_preview_config
UnstableMediaPreviewConfig(GlobalUnstableMediaPreviewConfigEvent)
io.element.msc4278.media_preview_config
AccountImagePack(AccountImagePackEvent)
m.image_pack
This variant uses the unstable type im.ponies.user_emotes.
This variant can also be deserialized from the m.image_pack type.
ImagePackRooms(ImagePackRoomsEvent)
m.image_pack.rooms
This variant uses the unstable type im.ponies.emote_rooms.
This variant can also be deserialized from the m.image_pack.rooms type.
RecentEmoji(RecentEmojiEvent)
m.recent_emoji
Implementations
Sourceimpl AnyGlobalAccountDataEvent
impl AnyGlobalAccountDataEvent
Sourcepub fn event_type(&self) -> GlobalAccountDataEventType
pub fn event_type(&self) -> GlobalAccountDataEventType
Returns the type of this event.
Sourcepub fn content(&self) -> AnyGlobalAccountDataEventContent
pub fn content(&self) -> AnyGlobalAccountDataEventContent
Returns the content for this event.