#[non_exhaustive]pub enum AnyPossiblyRedactedStateEventContent {
Show 27 variants
PolicyRuleRoom(PossiblyRedactedPolicyRuleRoomEventContent),
PolicyRuleServer(PossiblyRedactedPolicyRuleServerEventContent),
PolicyRuleUser(PossiblyRedactedPolicyRuleUserEventContent),
RoomAliases(PossiblyRedactedRoomAliasesEventContent),
RoomAvatar(PossiblyRedactedRoomAvatarEventContent),
RoomCanonicalAlias(PossiblyRedactedRoomCanonicalAliasEventContent),
RoomCreate(PossiblyRedactedRoomCreateEventContent),
RoomEncryption(PossiblyRedactedRoomEncryptionEventContent),
RoomEncrypted(PossiblyRedactedStateRoomEncryptedEventContent),
RoomGuestAccess(PossiblyRedactedRoomGuestAccessEventContent),
RoomHistoryVisibility(PossiblyRedactedRoomHistoryVisibilityEventContent),
RoomJoinRules(PossiblyRedactedRoomJoinRulesEventContent),
RoomLanguage(PossiblyRedactedRoomLanguageEventContent),
RoomMember(PossiblyRedactedRoomMemberEventContent),
RoomName(PossiblyRedactedRoomNameEventContent),
RoomPinnedEvents(PossiblyRedactedRoomPinnedEventsEventContent),
RoomPowerLevels(PossiblyRedactedRoomPowerLevelsEventContent),
RoomServerAcl(PossiblyRedactedRoomServerAclEventContent),
RoomThirdPartyInvite(PossiblyRedactedRoomThirdPartyInviteEventContent),
RoomTombstone(PossiblyRedactedRoomTombstoneEventContent),
RoomTopic(PossiblyRedactedRoomTopicEventContent),
SpaceChild(PossiblyRedactedSpaceChildEventContent),
SpaceParent(PossiblyRedactedSpaceParentEventContent),
RoomImagePack(PossiblyRedactedRoomImagePackEventContent),
BeaconInfo(PossiblyRedactedBeaconInfoEventContent),
CallMember(PossiblyRedactedCallMemberEventContent),
MemberHints(PossiblyRedactedMemberHintsEventContent),
}Expand description
Any state event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
PolicyRuleRoom(PossiblyRedactedPolicyRuleRoomEventContent)
m.policy.rule.room
PolicyRuleServer(PossiblyRedactedPolicyRuleServerEventContent)
m.policy.rule.server
PolicyRuleUser(PossiblyRedactedPolicyRuleUserEventContent)
m.policy.rule.user
RoomAliases(PossiblyRedactedRoomAliasesEventContent)
m.room.aliases
RoomAvatar(PossiblyRedactedRoomAvatarEventContent)
m.room.avatar
RoomCanonicalAlias(PossiblyRedactedRoomCanonicalAliasEventContent)
m.room.canonical_alias
RoomCreate(PossiblyRedactedRoomCreateEventContent)
m.room.create
RoomEncryption(PossiblyRedactedRoomEncryptionEventContent)
m.room.encryption
RoomEncrypted(PossiblyRedactedStateRoomEncryptedEventContent)
m.room.encrypted
RoomGuestAccess(PossiblyRedactedRoomGuestAccessEventContent)
m.room.guest_access
RoomHistoryVisibility(PossiblyRedactedRoomHistoryVisibilityEventContent)
m.room.history_visibility
RoomJoinRules(PossiblyRedactedRoomJoinRulesEventContent)
m.room.join_rules
RoomLanguage(PossiblyRedactedRoomLanguageEventContent)
m.room.language
This variant uses the unstable type org.matrix.msc4334.room.language.
This variant can also be deserialized from the m.room.language type.
RoomMember(PossiblyRedactedRoomMemberEventContent)
m.room.member
RoomName(PossiblyRedactedRoomNameEventContent)
m.room.name
RoomPinnedEvents(PossiblyRedactedRoomPinnedEventsEventContent)
m.room.pinned_events
RoomPowerLevels(PossiblyRedactedRoomPowerLevelsEventContent)
m.room.power_levels
RoomServerAcl(PossiblyRedactedRoomServerAclEventContent)
m.room.server_acl
RoomThirdPartyInvite(PossiblyRedactedRoomThirdPartyInviteEventContent)
m.room.third_party_invite
RoomTombstone(PossiblyRedactedRoomTombstoneEventContent)
m.room.tombstone
RoomTopic(PossiblyRedactedRoomTopicEventContent)
m.room.topic
SpaceChild(PossiblyRedactedSpaceChildEventContent)
m.space.child
SpaceParent(PossiblyRedactedSpaceParentEventContent)
m.space.parent
RoomImagePack(PossiblyRedactedRoomImagePackEventContent)
m.image_pack
This variant uses the unstable type im.ponies.room_emotes.
This variant can also be deserialized from the m.image_pack type.
BeaconInfo(PossiblyRedactedBeaconInfoEventContent)
m.beacon_info
This variant uses the unstable type org.matrix.msc3672.beacon_info.
This variant can also be deserialized from the m.beacon_info type.
CallMember(PossiblyRedactedCallMemberEventContent)
m.call.member
This variant uses the unstable type org.matrix.msc3401.call.member.
This variant can also be deserialized from the m.call.member type.
MemberHints(PossiblyRedactedMemberHintsEventContent)
m.member_hints
This variant uses the unstable type io.element.functional_members.
This variant can also be deserialized from the m.member_hints type.