AnyStateEvent

Enum AnyStateEvent 

#[non_exhaustive]
pub enum AnyStateEvent {
Show 28 variants PolicyRuleRoom(PolicyRuleRoomEvent), PolicyRuleServer(PolicyRuleServerEvent), PolicyRuleUser(PolicyRuleUserEvent), RoomAvatar(RoomAvatarEvent), RoomCanonicalAlias(RoomCanonicalAliasEvent), RoomCreate(RoomCreateEvent), RoomEncryption(RoomEncryptionEvent), RoomEncrypted(StateRoomEncryptedEvent), RoomGuestAccess(RoomGuestAccessEvent), RoomHistoryVisibility(RoomHistoryVisibilityEvent), RoomImagePack(RoomImagePackEvent), RoomJoinRules(RoomJoinRulesEvent), RoomLanguage(RoomLanguageEvent), RoomMember(RoomMemberEvent), RoomName(RoomNameEvent), RoomPinnedEvents(RoomPinnedEventsEvent), RoomPolicy(RoomPolicyEvent), RoomPowerLevels(RoomPowerLevelsEvent), RoomServerAcl(RoomServerAclEvent), RoomThirdPartyInvite(RoomThirdPartyInviteEvent), RoomTombstone(RoomTombstoneEvent), RoomTopic(RoomTopicEvent), RoomPresenceSharing(RoomPresenceSharingEvent), SpaceChild(SpaceChildEvent), SpaceParent(SpaceParentEvent), BeaconInfo(BeaconInfoEvent), CallMember(CallMemberEvent), MemberHints(MemberHintsEvent),
}
Any state event.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


PolicyRuleRoom(PolicyRuleRoomEvent)

m.policy.rule.room



PolicyRuleServer(PolicyRuleServerEvent)

m.policy.rule.server



PolicyRuleUser(PolicyRuleUserEvent)

m.policy.rule.user



RoomAvatar(RoomAvatarEvent)

m.room.avatar



RoomCanonicalAlias(RoomCanonicalAliasEvent)

m.room.canonical_alias



RoomCreate(RoomCreateEvent)

m.room.create



RoomEncryption(RoomEncryptionEvent)

m.room.encryption



RoomEncrypted(StateRoomEncryptedEvent)

m.room.encrypted



RoomGuestAccess(RoomGuestAccessEvent)

m.room.guest_access



RoomHistoryVisibility(RoomHistoryVisibilityEvent)

m.room.history_visibility



RoomImagePack(RoomImagePackEvent)

m.room.image_pack



RoomJoinRules(RoomJoinRulesEvent)

m.room.join_rules



RoomLanguage(RoomLanguageEvent)

m.room.language

This variant uses the unstable type org.matrix.msc4334.room.language.

This variant can also be deserialized from the m.room.language type.



RoomMember(RoomMemberEvent)

m.room.member



RoomName(RoomNameEvent)

m.room.name



RoomPinnedEvents(RoomPinnedEventsEvent)

m.room.pinned_events



RoomPolicy(RoomPolicyEvent)

m.room.policy



RoomPowerLevels(RoomPowerLevelsEvent)

m.room.power_levels



RoomServerAcl(RoomServerAclEvent)

m.room.server_acl



RoomThirdPartyInvite(RoomThirdPartyInviteEvent)

m.room.third_party_invite



RoomTombstone(RoomTombstoneEvent)

m.room.tombstone



RoomTopic(RoomTopicEvent)

m.room.topic



RoomPresenceSharing(RoomPresenceSharingEvent)

m.room.presence_sharing

This variant uses the unstable type org.continuwuity.presence_v2.msc4495.room.presence_sharing.

This variant can also be deserialized from the m.room.presence_sharing type.



SpaceChild(SpaceChildEvent)

m.space.child



SpaceParent(SpaceParentEvent)

m.space.parent



BeaconInfo(BeaconInfoEvent)

m.beacon_info

This variant uses the unstable type org.matrix.msc3672.beacon_info.

This variant can also be deserialized from the m.beacon_info type.



CallMember(CallMemberEvent)

m.call.member

This variant uses the unstable type org.matrix.msc3401.call.member.

This variant can also be deserialized from the m.call.member type.



MemberHints(MemberHintsEvent)

m.member_hints

This variant uses the unstable type io.element.functional_members.

This variant can also be deserialized from the m.member_hints type.

Implementations

Source

impl AnyStateEvent

pub fn event_type(&self) -> StateEventType

Returns the type of this event.

pub fn original_content(&self) -> Option<AnyStateEventContent>

Returns the content for this event if it is not redacted, or None if it is.

pub fn is_redacted(&self) -> bool

Returns whether this event is redacted.

pub fn content(&self) -> AnyPossiblyRedactedStateEventContent

Returns the content for this event.

pub fn content_change(&self) -> AnyStateEventContentChange

Returns the content change of this state event.

pub fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch

Returns this event’s origin_server_ts field.

pub fn room_id(&self) -> &RoomId

Returns this event’s room_id field.

pub fn event_id(&self) -> &EventId

Returns this event’s event_id field.

pub fn sender(&self) -> &UserId

Returns this event’s sender field.

pub fn state_key(&self) -> &str

Returns this event’s state_key field.

pub fn transaction_id(&self) -> Option<&TransactionId>

Returns this event’s transaction_id from inside unsigned, if there is one.