#[non_exhaustive]pub enum AnySyncStateEvent {
Show 27 variants
PolicyRuleRoom(SyncPolicyRuleRoomEvent),
PolicyRuleServer(SyncPolicyRuleServerEvent),
PolicyRuleUser(SyncPolicyRuleUserEvent),
RoomAliases(SyncRoomAliasesEvent),
RoomAvatar(SyncRoomAvatarEvent),
RoomCanonicalAlias(SyncRoomCanonicalAliasEvent),
RoomCreate(SyncRoomCreateEvent),
RoomEncryption(SyncRoomEncryptionEvent),
RoomEncrypted(SyncStateRoomEncryptedEvent),
RoomGuestAccess(SyncRoomGuestAccessEvent),
RoomHistoryVisibility(SyncRoomHistoryVisibilityEvent),
RoomJoinRules(SyncRoomJoinRulesEvent),
RoomLanguage(SyncRoomLanguageEvent),
RoomMember(SyncRoomMemberEvent),
RoomName(SyncRoomNameEvent),
RoomPinnedEvents(SyncRoomPinnedEventsEvent),
RoomPowerLevels(SyncRoomPowerLevelsEvent),
RoomServerAcl(SyncRoomServerAclEvent),
RoomThirdPartyInvite(SyncRoomThirdPartyInviteEvent),
RoomTombstone(SyncRoomTombstoneEvent),
RoomTopic(SyncRoomTopicEvent),
SpaceChild(SyncSpaceChildEvent),
SpaceParent(SyncSpaceParentEvent),
RoomImagePack(SyncRoomImagePackEvent),
BeaconInfo(SyncBeaconInfoEvent),
CallMember(SyncCallMemberEvent),
MemberHints(SyncMemberHintsEvent),
}Expand description
Any state event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
PolicyRuleRoom(SyncPolicyRuleRoomEvent)
m.policy.rule.room
PolicyRuleServer(SyncPolicyRuleServerEvent)
m.policy.rule.server
PolicyRuleUser(SyncPolicyRuleUserEvent)
m.policy.rule.user
RoomAliases(SyncRoomAliasesEvent)
m.room.aliases
RoomAvatar(SyncRoomAvatarEvent)
m.room.avatar
RoomCanonicalAlias(SyncRoomCanonicalAliasEvent)
m.room.canonical_alias
RoomCreate(SyncRoomCreateEvent)
m.room.create
RoomEncryption(SyncRoomEncryptionEvent)
m.room.encryption
RoomEncrypted(SyncStateRoomEncryptedEvent)
m.room.encrypted
RoomGuestAccess(SyncRoomGuestAccessEvent)
m.room.guest_access
RoomHistoryVisibility(SyncRoomHistoryVisibilityEvent)
m.room.history_visibility
RoomJoinRules(SyncRoomJoinRulesEvent)
m.room.join_rules
RoomLanguage(SyncRoomLanguageEvent)
m.room.language
This variant uses the unstable type org.matrix.msc4334.room.language.
This variant can also be deserialized from the m.room.language type.
RoomMember(SyncRoomMemberEvent)
m.room.member
RoomName(SyncRoomNameEvent)
m.room.name
RoomPinnedEvents(SyncRoomPinnedEventsEvent)
m.room.pinned_events
RoomPowerLevels(SyncRoomPowerLevelsEvent)
m.room.power_levels
RoomServerAcl(SyncRoomServerAclEvent)
m.room.server_acl
RoomThirdPartyInvite(SyncRoomThirdPartyInviteEvent)
m.room.third_party_invite
RoomTombstone(SyncRoomTombstoneEvent)
m.room.tombstone
RoomTopic(SyncRoomTopicEvent)
m.room.topic
SpaceChild(SyncSpaceChildEvent)
m.space.child
SpaceParent(SyncSpaceParentEvent)
m.space.parent
RoomImagePack(SyncRoomImagePackEvent)
m.image_pack
This variant uses the unstable type im.ponies.room_emotes.
This variant can also be deserialized from the m.image_pack type.
BeaconInfo(SyncBeaconInfoEvent)
m.beacon_info
This variant uses the unstable type org.matrix.msc3672.beacon_info.
This variant can also be deserialized from the m.beacon_info type.
CallMember(SyncCallMemberEvent)
m.call.member
This variant uses the unstable type org.matrix.msc3401.call.member.
This variant can also be deserialized from the m.call.member type.
MemberHints(SyncMemberHintsEvent)
m.member_hints
This variant uses the unstable type io.element.functional_members.
This variant can also be deserialized from the m.member_hints type.
Implementations
Sourceimpl AnySyncStateEvent
impl AnySyncStateEvent
Sourcepub fn event_type(&self) -> StateEventType
pub fn event_type(&self) -> StateEventType
Returns the type of this event.
Sourcepub fn original_content(&self) -> Option<AnyStateEventContent>
pub fn original_content(&self) -> Option<AnyStateEventContent>
Returns the content for this event if it is not redacted, or None if it is.
Sourcepub fn is_redacted(&self) -> bool
pub fn is_redacted(&self) -> bool
Returns whether this event is redacted.
Sourcepub fn content(&self) -> AnyFullStateEventContent
pub fn content(&self) -> AnyFullStateEventContent
Returns the content of this state event.
Sourcepub fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch
pub fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch
Returns this event’s origin_server_ts field.
Sourcepub fn transaction_id(&self) -> Option<&TransactionId>
pub fn transaction_id(&self) -> Option<&TransactionId>
Returns this event’s transaction_id from inside unsigned, if there is one.
Sourceimpl AnySyncStateEvent
impl AnySyncStateEvent
Sourcepub fn into_full_event(self, room_id: OwnedRoomId) -> AnyStateEvent
pub fn into_full_event(self, room_id: OwnedRoomId) -> AnyStateEvent
Convert this sync event into a full event (one with a room_id field).