#[non_exhaustive]pub enum EphemeralRoomEventType {
Receipt,
Typing,
}Expand description
The type of EphemeralRoomEvent this is.
This type can hold an arbitrary string. To build events with a custom type, convert it
from a string with ::from() / .into(). To check for events that are not available as a
documented variant here, use its string representation, obtained through .to_string().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl EphemeralRoomEventType
impl EphemeralRoomEventType
Sourcepub fn from_string(s: String) -> Self
pub fn from_string(s: String) -> Self
Construct a variant of the enum from a string.