#[non_exhaustive]pub enum RoomAccountDataEventType {
FullyRead,
Tag,
MarkedUnread,
UnstableMarkedUnread,
MediaPreviewConfig,
UnstableMediaPreviewConfig,
SpaceOrder,
}Expand description
The type of RoomAccountDataEvent this is.
This type can hold an arbitrary string. To build events with a custom type, convert it
from a string with ::from() / .into(). To check for events that are not available as a
documented variant here, use its string representation, obtained through .to_string().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FullyRead
m.fully_read
Tag
m.tag
MarkedUnread
m.marked_unread
UnstableMarkedUnread
com.famedly.marked_unread
MediaPreviewConfig
m.media_preview_config
UnstableMediaPreviewConfig
io.element.msc4278.media_preview_config
SpaceOrder
m.space_order
This variant uses the unstable type org.matrix.msc3230.space_order.
This variant can also be deserialized from the m.space_order type.
Implementations
Sourceimpl RoomAccountDataEventType
impl RoomAccountDataEventType
Sourcepub fn from_string(s: String) -> Self
pub fn from_string(s: String) -> Self
Construct a variant of the enum from a string.