StateEvent

Enum StateEvent 

pub enum StateEvent<C: StaticStateEventContent + RedactContent>{
    Original(OriginalStateEvent<C>),
    Redacted(RedactedStateEvent<C::Redacted>),
}
A possibly-redacted state event.

StateEvent implements the comparison traits using only the event_id field, a sorted list would be sorted lexicographically based on the event’s EventId.

Variants



Original(OriginalStateEvent<C>)

Original, unredacted form of the event.



Redacted(RedactedStateEvent<C::Redacted>)

Redacted form of the event with minimal fields.

Implementations

Source

impl<C> StateEvent<C>

pub fn event_type(&self) -> StateEventType

Returns the type of this event.

pub fn event_id(&self) -> &EventId

Returns this event’s event_id field.

pub fn sender(&self) -> &UserId

Returns this event’s sender field.

pub fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch

Returns this event’s origin_server_ts field.

pub fn room_id(&self) -> &RoomId

Returns this event’s room_id field.

pub fn state_key(&self) -> &C::StateKey

Returns this event’s state_key field.

pub fn as_original(&self) -> Option<&OriginalStateEvent<C>>

Get the inner OriginalStateEvent if this is an unredacted event.

Source

impl StateEvent<RoomGuestAccessEventContent>

pub fn guest_access(&self) -> &GuestAccess

Obtain the guest access policy, regardless of whether this event is redacted.

Source

impl StateEvent<RoomHistoryVisibilityEventContent>

pub fn history_visibility(&self) -> &HistoryVisibility

Obtain the history visibility, regardless of whether this event is redacted.

Source

impl StateEvent<RoomJoinRulesEventContent>

pub fn join_rule(&self) -> &JoinRule

Obtain the join rule, regardless of whether this event is redacted.

Source

impl StateEvent<RoomMemberEventContent>

pub fn membership(&self) -> &MembershipState

Obtain the membership state, regardless of whether this event is redacted.

pub fn should_redact_events(&self) -> bool

Determines whether the user’s events should be redacted based on their membership.

Using MSC4293, if redact_events is true, the sender is different to the state key, and the membership is ban or leave (kick), true is returned. Otherwise, the flag should be ignored, and false is returned.

Source

impl StateEvent<RoomPowerLevelsEventContent>

pub fn power_levels( &self, rules: &AuthorizationRules, creators: Vec<OwnedUserId>, ) -> RoomPowerLevels

Obtain the effective power levels, regardless of whether this event is redacted.