StateEventType

Enum StateEventType 

#[non_exhaustive]
pub enum StateEventType {
Show 28 variants PolicyRuleRoom, PolicyRuleServer, PolicyRuleUser, RoomAvatar, RoomCanonicalAlias, RoomCreate, RoomEncryption, RoomEncrypted, RoomGuestAccess, RoomHistoryVisibility, RoomImagePack, RoomJoinRules, RoomLanguage, RoomMember, RoomName, RoomPinnedEvents, RoomPolicy, RoomPowerLevels, RoomServerAcl, RoomThirdPartyInvite, RoomTombstone, RoomTopic, RoomPresenceSharing, SpaceChild, SpaceParent, BeaconInfo, CallMember, MemberHints,
}
The type of StateEvent this is.

This type can hold an arbitrary string. To build events with a custom type, convert it from a string with ::from() / .into(). To check for events that are not available as a documented variant here, use its string representation, obtained through .to_string().

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


PolicyRuleRoom

m.policy.rule.room



PolicyRuleServer

m.policy.rule.server



PolicyRuleUser

m.policy.rule.user



RoomAvatar

m.room.avatar



RoomCanonicalAlias

m.room.canonical_alias



RoomCreate

m.room.create



RoomEncryption

m.room.encryption



RoomEncrypted

m.room.encrypted



RoomGuestAccess

m.room.guest_access



RoomHistoryVisibility

m.room.history_visibility



RoomImagePack

m.room.image_pack



RoomJoinRules

m.room.join_rules



RoomLanguage

m.room.language

This variant uses the unstable type org.matrix.msc4334.room.language.

This variant can also be deserialized from the m.room.language type.



RoomMember

m.room.member



RoomName

m.room.name



RoomPinnedEvents

m.room.pinned_events



RoomPolicy

m.room.policy



RoomPowerLevels

m.room.power_levels



RoomServerAcl

m.room.server_acl



RoomThirdPartyInvite

m.room.third_party_invite



RoomTombstone

m.room.tombstone



RoomTopic

m.room.topic



RoomPresenceSharing

m.room.presence_sharing

This variant uses the unstable type org.continuwuity.presence_v2.msc4495.room.presence_sharing.

This variant can also be deserialized from the m.room.presence_sharing type.



SpaceChild

m.space.child



SpaceParent

m.space.parent



BeaconInfo

m.beacon_info

This variant uses the unstable type org.matrix.msc3672.beacon_info.

This variant can also be deserialized from the m.beacon_info type.



CallMember

m.call.member

This variant uses the unstable type org.matrix.msc3401.call.member.

This variant can also be deserialized from the m.call.member type.



MemberHints

m.member_hints

This variant uses the unstable type io.element.functional_members.

This variant can also be deserialized from the m.member_hints type.