#[non_exhaustive]pub enum ToDeviceEventType {
Show 18 variants
Dummy,
RoomKey,
RoomKeyBundle,
RoomKeyRequest,
RoomKeyWithheld,
ForwardedRoomKey,
KeyVerificationRequest,
KeyVerificationReady,
KeyVerificationStart,
KeyVerificationCancel,
KeyVerificationAccept,
KeyVerificationKey,
KeyVerificationMac,
KeyVerificationDone,
RoomEncrypted,
SecretRequest,
SecretSend,
SecretPush,
}Expand description
The type of ToDeviceEvent this is.
This type can hold an arbitrary string. To build events with a custom type, convert it
from a string with ::from() / .into(). To check for events that are not available as a
documented variant here, use its string representation, obtained through .to_string().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Dummy
m.dummy
RoomKey
m.room_key
RoomKeyBundle
m.room_key_bundle
This variant uses the unstable type io.element.msc4268.room_key_bundle.
This variant can also be deserialized from the m.room_key_bundle type.
RoomKeyRequest
m.room_key_request
RoomKeyWithheld
m.room_key.withheld
ForwardedRoomKey
m.forwarded_room_key
KeyVerificationRequest
m.key.verification.request
KeyVerificationReady
m.key.verification.ready
KeyVerificationStart
m.key.verification.start
KeyVerificationCancel
m.key.verification.cancel
KeyVerificationAccept
m.key.verification.accept
KeyVerificationKey
m.key.verification.key
KeyVerificationMac
m.key.verification.mac
KeyVerificationDone
m.key.verification.done
RoomEncrypted
m.room.encrypted
SecretRequest
m.secret.request
SecretSend
m.secret.send
SecretPush
m.secret.push
This variant uses the unstable type io.element.msc4385.secret.push.
This variant can also be deserialized from the m.secret.push type.
Implementations
Sourceimpl ToDeviceEventType
impl ToDeviceEventType
Sourcepub fn from_string(s: String) -> Self
pub fn from_string(s: String) -> Self
Construct a variant of the enum from a string.