#[non_exhaustive]pub struct RedactedSyncStateEvent<C: RedactedStateEventContent> {
pub content: C,
pub event_id: OwnedEventId,
pub sender: OwnedUserId,
pub origin_server_ts: MilliSecondsSinceUnixEpoch,
pub state_key: C::StateKey,
pub unsigned: RedactedUnsigned,
}Expand description
A redacted state event without a room_id.
RedactedSyncStateEvent implements the comparison traits using only the event_id field, a
sorted list would be sorted lexicographically based on the event’s EventId.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.content: CData specific to the event type.
event_id: OwnedEventIdThe globally unique identifier for the event.
sender: OwnedUserIdThe fully-qualified ID of the user who sent this event.
origin_server_ts: MilliSecondsSinceUnixEpochTimestamp on the originating homeserver when this event was sent.
state_key: C::StateKeyA unique key which defines the overwriting semantics for this piece of room state.
This must be a string type, and is often an empty string.
A state event is keyed by its (type, state_key) tuple. Sending another state event with
the same tuple replaces the previous one.
unsigned: RedactedUnsignedAdditional key-value pairs not signed by the homeserver.
Implementations
Sourceimpl<C: RedactedStateEventContent> RedactedSyncStateEvent<C>
impl<C: RedactedStateEventContent> RedactedSyncStateEvent<C>
Sourcepub fn event_type(&self) -> StateEventType
pub fn event_type(&self) -> StateEventType
Get the event’s type.
Sourceimpl<C: RedactedStateEventContent> RedactedSyncStateEvent<C>
impl<C: RedactedStateEventContent> RedactedSyncStateEvent<C>
Sourcepub fn into_full_event(self, room_id: OwnedRoomId) -> RedactedStateEvent<C>
pub fn into_full_event(self, room_id: OwnedRoomId) -> RedactedStateEvent<C>
Convert this sync event into a full event, one with a room_id field.
Sourceimpl RedactedSyncStateEvent<RedactedRoomMemberEventContent>
impl RedactedSyncStateEvent<RedactedRoomMemberEventContent>
Sourcepub fn details(&self) -> MembershipDetails<'_>
pub fn details(&self) -> MembershipDetails<'_>
Obtain the details about this event that are required to calculate a membership change.
This is required when you want to calculate the change a redacted m.room.member event
made.
Sourcepub fn membership_change<'a>(
&'a self,
prev_details: Option<MembershipDetails<'a>>,
) -> MembershipChange<'a>
pub fn membership_change<'a>( &'a self, prev_details: Option<MembershipDetails<'a>>, ) -> MembershipChange<'a>
Helper function for membership change.
Since redacted events don’t have unsigned.prev_content, you have to pass the .details()
of the previous m.room.member event manually (if there is a previous m.room.member
event).
Check the specification for details.
Sourcepub fn should_redact_events(&self) -> bool
pub fn should_redact_events(&self) -> bool
Determines whether the user’s events should be redacted based on their membership.
Using MSC4293, if redact_events is true, the sender is different to the state key,
and the membership is ban or leave (kick), true is returned. Otherwise, the flag
should be ignored, and false is returned.