pub trait EventContentFromType: Sized {
// Required method
fn from_parts(event_type: &str, content: &RawJsonValue) -> Result<Self>;
}Expand description
Event content that can be deserialized with its event type.
Required Methods
Sourcefn from_parts(event_type: &str, content: &RawJsonValue) -> Result<Self>
fn from_parts(event_type: &str, content: &RawJsonValue) -> Result<Self>
Constructs this event content from the given event type and JSON.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".