#[non_exhaustive]pub enum AnyStateEvent {
Show 27 variants
PolicyRuleRoom(PolicyRuleRoomEvent),
PolicyRuleServer(PolicyRuleServerEvent),
PolicyRuleUser(PolicyRuleUserEvent),
RoomAliases(RoomAliasesEvent),
RoomAvatar(RoomAvatarEvent),
RoomCanonicalAlias(RoomCanonicalAliasEvent),
RoomCreate(RoomCreateEvent),
RoomEncryption(RoomEncryptionEvent),
RoomEncrypted(StateRoomEncryptedEvent),
RoomGuestAccess(RoomGuestAccessEvent),
RoomHistoryVisibility(RoomHistoryVisibilityEvent),
RoomJoinRules(RoomJoinRulesEvent),
RoomLanguage(RoomLanguageEvent),
RoomMember(RoomMemberEvent),
RoomName(RoomNameEvent),
RoomPinnedEvents(RoomPinnedEventsEvent),
RoomPowerLevels(RoomPowerLevelsEvent),
RoomServerAcl(RoomServerAclEvent),
RoomThirdPartyInvite(RoomThirdPartyInviteEvent),
RoomTombstone(RoomTombstoneEvent),
RoomTopic(RoomTopicEvent),
SpaceChild(SpaceChildEvent),
SpaceParent(SpaceParentEvent),
RoomImagePack(RoomImagePackEvent),
BeaconInfo(BeaconInfoEvent),
CallMember(CallMemberEvent),
MemberHints(MemberHintsEvent),
}Expand description
Any state event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
PolicyRuleRoom(PolicyRuleRoomEvent)
m.policy.rule.room
PolicyRuleServer(PolicyRuleServerEvent)
m.policy.rule.server
PolicyRuleUser(PolicyRuleUserEvent)
m.policy.rule.user
RoomAliases(RoomAliasesEvent)
m.room.aliases
RoomAvatar(RoomAvatarEvent)
m.room.avatar
RoomCanonicalAlias(RoomCanonicalAliasEvent)
m.room.canonical_alias
RoomCreate(RoomCreateEvent)
m.room.create
RoomEncryption(RoomEncryptionEvent)
m.room.encryption
RoomEncrypted(StateRoomEncryptedEvent)
m.room.encrypted
RoomGuestAccess(RoomGuestAccessEvent)
m.room.guest_access
RoomHistoryVisibility(RoomHistoryVisibilityEvent)
m.room.history_visibility
RoomJoinRules(RoomJoinRulesEvent)
m.room.join_rules
RoomLanguage(RoomLanguageEvent)
m.room.language
This variant uses the unstable type org.matrix.msc4334.room.language.
This variant can also be deserialized from the m.room.language type.
RoomMember(RoomMemberEvent)
m.room.member
RoomName(RoomNameEvent)
m.room.name
RoomPinnedEvents(RoomPinnedEventsEvent)
m.room.pinned_events
RoomPowerLevels(RoomPowerLevelsEvent)
m.room.power_levels
RoomServerAcl(RoomServerAclEvent)
m.room.server_acl
RoomThirdPartyInvite(RoomThirdPartyInviteEvent)
m.room.third_party_invite
RoomTombstone(RoomTombstoneEvent)
m.room.tombstone
RoomTopic(RoomTopicEvent)
m.room.topic
SpaceChild(SpaceChildEvent)
m.space.child
SpaceParent(SpaceParentEvent)
m.space.parent
RoomImagePack(RoomImagePackEvent)
m.image_pack
This variant uses the unstable type im.ponies.room_emotes.
This variant can also be deserialized from the m.image_pack type.
BeaconInfo(BeaconInfoEvent)
m.beacon_info
This variant uses the unstable type org.matrix.msc3672.beacon_info.
This variant can also be deserialized from the m.beacon_info type.
CallMember(CallMemberEvent)
m.call.member
This variant uses the unstable type org.matrix.msc3401.call.member.
This variant can also be deserialized from the m.call.member type.
MemberHints(MemberHintsEvent)
m.member_hints
This variant uses the unstable type io.element.functional_members.
This variant can also be deserialized from the m.member_hints type.
Implementations
Sourceimpl AnyStateEvent
impl AnyStateEvent
Sourcepub fn event_type(&self) -> StateEventType
pub fn event_type(&self) -> StateEventType
Returns the type of this event.
Sourcepub fn original_content(&self) -> Option<AnyStateEventContent>
pub fn original_content(&self) -> Option<AnyStateEventContent>
Returns the content for this event if it is not redacted, or None if it is.
Sourcepub fn is_redacted(&self) -> bool
pub fn is_redacted(&self) -> bool
Returns whether this event is redacted.
Sourcepub fn content(&self) -> AnyFullStateEventContent
pub fn content(&self) -> AnyFullStateEventContent
Returns the content of this state event.
Sourcepub fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch
pub fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch
Returns this event’s origin_server_ts field.
Sourcepub fn transaction_id(&self) -> Option<&TransactionId>
pub fn transaction_id(&self) -> Option<&TransactionId>
Returns this event’s transaction_id from inside unsigned, if there is one.